@@ -11,7 +11,6 @@ import (
 	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 	"github.com/jandedobbeleer/oh-my-posh/src/segments"
-	"github.com/jandedobbeleer/oh-my-posh/src/shell"
 	"github.com/jandedobbeleer/oh-my-posh/src/template"
 
 	c "golang.org/x/text/cases"
@@ -20,26 +19,27 @@ import (
 
 // Segment represent a single segment and it's configuration
 type Segment struct {
-	Type                SegmentType    `json:"type,omitempty" toml:"type,omitempty"`
-	Tips                []string       `json:"tips,omitempty" toml:"tips,omitempty"`
-	Style               SegmentStyle   `json:"style,omitempty" toml:"style,omitempty"`
-	PowerlineSymbol     string         `json:"powerline_symbol,omitempty" toml:"powerline_symbol,omitempty"`
-	InvertPowerline     bool           `json:"invert_powerline,omitempty" toml:"invert_powerline,omitempty"`
-	Foreground          string         `json:"foreground,omitempty" toml:"foreground,omitempty"`
-	ForegroundTemplates template.List  `json:"foreground_templates,omitempty" toml:"foreground_templates,omitempty"`
-	Background          string         `json:"background,omitempty" toml:"background,omitempty"`
-	BackgroundTemplates template.List  `json:"background_templates,omitempty" toml:"background_templates,omitempty"`
-	LeadingDiamond      string         `json:"leading_diamond,omitempty" toml:"leading_diamond,omitempty"`
-	TrailingDiamond     string         `json:"trailing_diamond,omitempty" toml:"trailing_diamond,omitempty"`
-	Template            string         `json:"template,omitempty" toml:"template,omitempty"`
-	Templates           template.List  `json:"templates,omitempty" toml:"templates,omitempty"`
-	TemplatesLogic      template.Logic `json:"templates_logic,omitempty" toml:"templates_logic,omitempty"`
-	Properties          properties.Map `json:"properties,omitempty" toml:"properties,omitempty"`
-	Interactive         bool           `json:"interactive,omitempty" toml:"interactive,omitempty"`
-	Alias               string         `json:"alias,omitempty" toml:"alias,omitempty"`
-	MaxWidth            int            `json:"max_width,omitempty" toml:"max_width,omitempty"`
-	MinWidth            int            `json:"min_width,omitempty" toml:"min_width,omitempty"`
-	Filler              string         `json:"filler,omitempty" toml:"filler,omitempty"`
+	Type                   SegmentType    `json:"type,omitempty" toml:"type,omitempty"`
+	Tips                   []string       `json:"tips,omitempty" toml:"tips,omitempty"`
+	Style                  SegmentStyle   `json:"style,omitempty" toml:"style,omitempty"`
+	PowerlineSymbol        string         `json:"powerline_symbol,omitempty" toml:"powerline_symbol,omitempty"`
+	LeadingPowerlineSymbol string         `json:"leading_powerline_symbol,omitempty" toml:"leading_powerline_symbol,omitempty"`
+	InvertPowerline        bool           `json:"invert_powerline,omitempty" toml:"invert_powerline,omitempty"`
+	Foreground             string         `json:"foreground,omitempty" toml:"foreground,omitempty"`
+	ForegroundTemplates    template.List  `json:"foreground_templates,omitempty" toml:"foreground_templates,omitempty"`
+	Background             string         `json:"background,omitempty" toml:"background,omitempty"`
+	BackgroundTemplates    template.List  `json:"background_templates,omitempty" toml:"background_templates,omitempty"`
+	LeadingDiamond         string         `json:"leading_diamond,omitempty" toml:"leading_diamond,omitempty"`
+	TrailingDiamond        string         `json:"trailing_diamond,omitempty" toml:"trailing_diamond,omitempty"`
+	Template               string         `json:"template,omitempty" toml:"template,omitempty"`
+	Templates              template.List  `json:"templates,omitempty" toml:"templates,omitempty"`
+	TemplatesLogic         template.Logic `json:"templates_logic,omitempty" toml:"templates_logic,omitempty"`
+	Properties             properties.Map `json:"properties,omitempty" toml:"properties,omitempty"`
+	Interactive            bool           `json:"interactive,omitempty" toml:"interactive,omitempty"`
+	Alias                  string         `json:"alias,omitempty" toml:"alias,omitempty"`
+	MaxWidth               int            `json:"max_width,omitempty" toml:"max_width,omitempty"`
+	MinWidth               int            `json:"min_width,omitempty" toml:"min_width,omitempty"`
+	Filler                 string         `json:"filler,omitempty" toml:"filler,omitempty"`
 
 	Enabled bool `json:"-" toml:"-"`
 
@@ -100,6 +100,8 @@ const (
 	AWS SegmentType = "aws"
 	// AZ writes the Azure subscription info we're currently in
 	AZ SegmentType = "az"
+	// AZD writes the Azure Developer CLI environment info we're current in
+	AZD SegmentType = "azd"
 	// AZFUNC writes current AZ func version
 	AZFUNC SegmentType = "azfunc"
 	// BATTERY writes the battery percentage
@@ -110,6 +112,8 @@ const (
 	BREWFATHER SegmentType = "brewfather"
 	// Buf segment writes the active buf version
 	BUF SegmentType = "buf"
+	// BUN writes the active bun version
+	BUN SegmentType = "bun"
 	// CARBONINTENSITY writes the actual and forecast carbon intensity in gCO2/kWh
 	CARBONINTENSITY SegmentType = "carbonintensity"
 	// cds (SAP CAP) version
@@ -275,11 +279,13 @@ var Segments = map[SegmentType]func() SegmentWriter{
 	ARGOCD:          func() SegmentWriter { return &segments.Argocd{} },
 	AWS:             func() SegmentWriter { return &segments.Aws{} },
 	AZ:              func() SegmentWriter { return &segments.Az{} },
+	AZD:             func() SegmentWriter { return &segments.Azd{} },
 	AZFUNC:          func() SegmentWriter { return &segments.AzFunc{} },
 	BATTERY:         func() SegmentWriter { return &segments.Battery{} },
 	BAZEL:           func() SegmentWriter { return &segments.Bazel{} },
 	BREWFATHER:      func() SegmentWriter { return &segments.Brewfather{} },
 	BUF:             func() SegmentWriter { return &segments.Buf{} },
+	BUN:             func() SegmentWriter { return &segments.Bun{} },
 	CARBONINTENSITY: func() SegmentWriter { return &segments.CarbonIntensity{} },
 	CDS:             func() SegmentWriter { return &segments.Cds{} },
 	CF:              func() SegmentWriter { return &segments.Cf{} },
@@ -364,7 +370,9 @@ func (segment *Segment) style() SegmentStyle {
 	if len(segment.styleCache) != 0 {
 		return segment.styleCache
 	}
+
 	segment.styleCache = segment.Style.Resolve(segment.env, segment.writer)
+
 	return segment.styleCache
 }
 
@@ -372,8 +380,10 @@ func (segment *Segment) shouldIncludeFolder() bool {
 	if segment.env == nil {
 		return true
 	}
+
 	cwdIncluded := segment.cwdIncluded()
 	cwdExcluded := segment.cwdExcluded()
+
 	return cwdIncluded && !cwdExcluded
 }
 
@@ -412,6 +422,7 @@ func (segment *Segment) cwdExcluded() bool {
 	if !ok {
 		value = segment.Properties[properties.IgnoreFolders]
 	}
+
 	list := properties.ParseStringArray(value)
 	return segment.env.DirMatchesOneOf(segment.env.Pwd(), list)
 }
@@ -422,6 +433,7 @@ func (segment *Segment) shouldInvokeWithTip(tip string) bool {
 			return true
 		}
 	}
+
 	return false
 }
 
@@ -429,9 +441,11 @@ func (segment *Segment) foreground() string {
 	if segment.colors == nil {
 		segment.colors = &ansi.Colors{}
 	}
+
 	if len(segment.colors.Foreground) == 0 {
 		segment.colors.Foreground = segment.ForegroundTemplates.FirstMatch(segment.writer, segment.env, segment.Foreground)
 	}
+
 	return segment.colors.Foreground
 }
 
@@ -439,9 +453,11 @@ func (segment *Segment) background() string {
 	if segment.colors == nil {
 		segment.colors = &ansi.Colors{}
 	}
+
 	if len(segment.colors.Background) == 0 {
 		segment.colors.Background = segment.BackgroundTemplates.FirstMatch(segment.writer, segment.env, segment.Background)
 	}
+
 	return segment.colors.Background
 }
 
@@ -474,19 +490,23 @@ func (segment *Segment) string() string {
 			return templatesResult
 		}
 	}
+
 	if len(segment.Template) == 0 {
 		segment.Template = segment.writer.Template()
 	}
+
 	tmpl := &template.Text{
 		Template:        segment.Template,
 		Context:         segment.writer,
 		Env:             segment.env,
 		TemplatesResult: templatesResult,
 	}
+
 	text, err := tmpl.Render()
 	if err != nil {
 		return err.Error()
 	}
+
 	return text
 }
 
@@ -494,10 +514,12 @@ func (segment *Segment) Name() string {
 	if len(segment.name) != 0 {
 		return segment.name
 	}
+
 	name := segment.Alias
 	if len(name) == 0 {
 		name = c.Title(language.English).String(string(segment.Type))
 	}
+
 	segment.name = name
 	return name
 }
@@ -555,20 +577,11 @@ func (segment *Segment) SetText() {
 	if !segment.Enabled {
 		return
 	}
+
 	segment.text = segment.string()
 	segment.Enabled = len(strings.ReplaceAll(segment.text, " ", "")) > 0
+
 	if !segment.Enabled {
 		segment.env.TemplateCache().RemoveSegmentData(segment.Name())
 	}
-
-	if segment.Interactive {
-		return
-	}
-	// we have to do this to prevent bash/zsh from misidentifying escape sequences
-	switch segment.env.Shell() {
-	case shell.BASH:
-		segment.text = strings.NewReplacer("`", "\\`", `\`, `\\`).Replace(segment.text)
-	case shell.ZSH:
-		segment.text = strings.NewReplacer("`", "\\`", `%`, `%%`).Replace(segment.text)
-	}
 }
