@@ -60,6 +60,7 @@ module.exports = {
         "segments/bazel",
         "segments/brewfather",
         "segments/buf",
+        "segments/bun",
         "segments/carbonintensity",
         "segments/cds",
         "segments/cf",
@@ -84,7 +85,6 @@ module.exports = {
         "segments/haskell",
         "segments/helm",
         "segments/ipify",
-        "segments/iterm",
         "segments/java",
         "segments/julia",
         "segments/kotlin",
